@@ -24,7 +24,9 @@ __version__ = "$Id$"
 #
 #-------------------------------------------------------------------------------
 
-from   layman.utils             import path
+import xml.etree.ElementTree as ET # Python 2.5
+
+from   layman.utils             import path, ensure_unicode
 from   layman.overlays.overlay  import Overlay
 
 #===============================================================================
@@ -37,18 +39,37 @@ class CvsOverlay(Overlay):
     ''' Handles cvs overlays.'''
 
     type = 'cvs'
+    type_key = 'cvs'
 
-    binary = '/usr/bin/cvs'
+    def __init__(self, xml, config, ignore = 0, quiet = False):
 
-    def __init__(self, xml, ignore = 0, quiet = False):
+        Overlay.__init__(self, xml, config, ignore, quiet)
 
-        Overlay.__init__(self, xml, ignore, quiet)
-
-        if '&subpath' in self.data.keys():
-            self.subpath = self.data['&subpath']
+        _subpath = xml.find('subpath')
+        if _subpath != None:
+            self.subpath = ensure_unicode(_subpath.text.strip())
+        elif 'subpath' in xml.attrib:
+            self.subpath = ensure_unicode(xml.attrib['subpath'])
         else:
             self.subpath = ''
 
+    def __eq__(self, other):
+        res = super(CvsOverlay, self).__eq__(other) \
+            and self.subpath == other.subpath
+        return res
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    # overrider
+    def to_xml(self):
+        repo = super(CvsOverlay, self).to_xml()
+        if self.subpath:
+            _subpath = ET.Element('subpath')
+            _subpath.text = self.subpath
+            repo.append(_subpath)
+        return repo
+
     def add(self, base, quiet = False):
         '''Add overlay.'''
 
@@ -59,8 +80,8 @@ class CvsOverlay(Overlay):
         else:
             quiet_option = ''
 
-        return self.cmd('cd "' + base + '" && CVSROOT="' + self.src + '" ' + 
-                        self.binary + quiet_option + ' co -d "' + self.name 
+        return self.cmd('cd "' + base + '" && CVSROOT="' + self.src + '" ' +
+                        self.command() + quiet_option + ' co -d "' + self.name
                         + '" "' + self.subpath + '"' )
 
     def sync(self, base, quiet = False):
@@ -74,10 +95,10 @@ class CvsOverlay(Overlay):
             quiet_option = ''
 
         return self.cmd('cd "' + path([base, self.name]) + '" && ' +
-                        self.binary + quiet_option + ' update -d')
+                        self.command() + quiet_option + ' update -d')
 
     def supported(self):
         '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.binary,  'cvs',
+        return Overlay.supported(self, [(self.command(),  'cvs',
                                          'dev-util/cvs'),])
